<?php

namespace Drupal\Tests\simple_date_block\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests the Simple Date Block functionality.
 *
 * @group simple_date_block
 */
class SimpleDateBlockTest extends BrowserTestBase {

  /**
   * The default theme to use for testing.
   *
   * @var string
   */
  protected $defaultTheme = 'stark';

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['simple_date_block', 'block'];

  /**
   * Tests the block configuration and rendering.
   */
  public function testSimpleDateBlock() {
    // Create an admin user with permission to manage blocks.
    $admin_user = $this->drupalCreateUser(['administer blocks']);
    $this->drupalLogin($admin_user);

    // Place the block in the content region.
    $this->drupalGet('admin/structure/block');
    $this->submitForm([
      'region' => 'content',
      'id' => 'simple_date_block',
    ], 'Save block');

    // Configure the block with a specific format and timezone.
    $this->drupalGet('admin/structure/block/manage/simple_date_block');
    $edit = [
      'settings[simple_date_block_format_type]' => 'Y-m-d',
      'settings[simple_date_block_timezone]' => 'UTC',
      'settings[simple_date_block_relative]' => 0,
      'settings[simple_date_block_custom_date]' => '',
    ];
    $this->submitForm($edit, 'Save block');

    // Verify the block output on the front page.
    $this->drupalGet('<front>');
    $this->assertSession()->responseContains(date('Y-m-d'));

    // Test relative time.
    $this->drupalGet('admin/structure/block/manage/simple_date_block');
    $edit['settings[simple_date_block_relative]'] = 1;
    $this->submitForm($edit, 'Save block');
    $this->drupalGet('<front>');
    $this->assertSession()->responseContains('seconds ago');

    // Test custom timestamp.
    $custom_timestamp = 1697059200; // Oct 12, 2023.
    $this->drupalGet('admin/structure/block/manage/simple_date_block');
    $edit['settings[simple_date_block_relative]'] = 0;
    $edit['settings[simple_date_block_format_type]'] = 'F j, Y';
    $edit['settings[simple_date_block_custom_date]'] = $custom_timestamp;
    $this->submitForm($edit, 'Save block');
    $this->drupalGet('<front>');
    $this->assertSession()->responseContains('October 12, 2023');

    // Test invalid custom timestamp.
    $this->drupalGet('admin/structure/block/manage/simple_date_block');
    $edit['settings[simple_date_block_custom_date]'] = 'invalid';
    $this->submitForm($edit, 'Save block');
    $this->assertSession()->responseContains('The custom date must be a valid Unix timestamp');
  }
}
